==> py_pdf_term-1.0.0.tar.gz: py_pdf_term-1.0.0/py_pdf_term/methods/_methods/rankers/base.py <==
from abc import ABCMeta, abstractmethod
from typing import Generic, List

from py_pdf_term.candidates import DomainCandidateTermList

from ..data import MethodTermRanking
from ..rankingdata.base import RankingData


class BaseSingleDomainRanker(Generic[RankingData], metaclass=ABCMeta):
    """Base class for term rankers with an algorithm which does not require cross-domain
    information.
    """

    def __init__(self) -> None:
        pass

    @abstractmethod
    def rank_terms(
        self,
        domain_candidates: DomainCandidateTermList,
        ranking_data: RankingData,
    ) -> MethodTermRanking:
        """Rank candidate terms in domain-specific PDF documents.

        Args
        ----
            domain_candidates:
                A list of candidate terms in domain-specific PDF documents.
            ranking_data:
                Metadata to rank candidate terms in PDF documents.

        Returns
        -------
            MethodTermRanking:
                A ranking result of candidate terms in PDF documents.
        """

        raise NotImplementedError(f"{self.__class__.__name__}.rank_terms()")


class BaseMultiDomainRanker(Generic[RankingData], metaclass=ABCMeta):
    """Base class for term rankers with an algorithm which requires cross-domain
    information.
    """

    def __init__(self) -> None:
        pass

    @abstractmethod
    def rank_terms(
        self,
        domain_candidates: DomainCandidateTermList,
        ranking_data_list: List[RankingData],
    ) -> MethodTermRanking:
        """Rank candidate terms in domain-specific PDF documents.

        Args
        ----
            domain_candidates:
                A list of candidate terms in domain-specific PDF documents.
            ranking_data_list:
                List of metadata to rank candidate terms in PDF documents for each
                domain.

        Returns
        -------
            MethodTermRanking:
                A ranking result of candidate terms in PDF documents.
        """

        raise NotImplementedError(f"{self.__class__.__name__}.rank_terms()")

==> py_pdf_term-1.0.2.tar.gz: py_pdf_term-1.0.2/py_pdf_term/methods/_methods/rankers/base.py <==
from abc import ABCMeta, abstractmethod
from typing import Generic

from py_pdf_term.candidates import DomainCandidateTermList

from ..data import MethodTermRanking
from ..rankingdata.base import RankingData


class BaseSingleDomainRanker(Generic[RankingData], metaclass=ABCMeta):
    """Base class for term rankers with an algorithm which does not require cross-domain
    information.
    """

    def __init__(self) -> None:
        pass

    @abstractmethod
    def rank_terms(
        self,
        domain_candidates: DomainCandidateTermList,
        ranking_data: RankingData,
    ) -> MethodTermRanking:
        """Rank candidate terms in domain-specific PDF documents.

        Args
        ----
            domain_candidates:
                List of candidate terms in domain-specific PDF documents.
            ranking_data:
                Metadata to rank candidate terms in PDF documents.

        Returns
        -------
            MethodTermRanking:
                Ranking result of candidate terms in PDF documents.
        """

        raise NotImplementedError(f"{self.__class__.__name__}.rank_terms()")


class BaseMultiDomainRanker(Generic[RankingData], metaclass=ABCMeta):
    """Base class for term rankers with an algorithm which requires cross-domain
    information.
    """

    def __init__(self) -> None:
        pass

    @abstractmethod
    def rank_terms(
        self,
        domain_candidates: DomainCandidateTermList,
        ranking_data_list: list[RankingData],
    ) -> MethodTermRanking:
        """Rank candidate terms in domain-specific PDF documents.

        Args
        ----
            domain_candidates:
                List of candidate terms in domain-specific PDF documents.
            ranking_data_list:
                List of metadata to rank candidate terms in PDF documents for each
                domain.

        Returns
        -------
            MethodTermRanking:
                Ranking result of candidate terms in PDF documents.
        """

        raise NotImplementedError(f"{self.__class__.__name__}.rank_terms()")
